@@ -1,6 +1,7 @@
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let img_url: String = nekosbest::get(nekosbest::Category::Pat).await?;
+    let resp = nekosbest::get(nekosbest::Category::Pat).await?;
+    let img_url = resp.url;
     println!("{}", img_url);
     Ok(())
 }
