@@ -1,6 +1,7 @@
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let img_urls: Vec<String> = nekosbest::get_amount(nekosbest::Category::Nekos, 20).await?;
+    let resp = nekosbest::get_amount(nekosbest::Category::Nekos, 3).await?;
+    let img_urls = resp.url;
     println!("{:?}", img_urls);
     Ok(())
 }
